/*
** Module   : MenuWidget.java
** Abstract : server side menu widget implementation
**
** Copyright (c) 2014-2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------------------Description-----------------------------
** 001 VIG 20141029          Created initial version.
*/
package com.goldencode.p2j.ui;

import java.lang.reflect.*;

import com.goldencode.p2j.util.*;

/**
 * This class represents menu widget.
 */
@LegacyResource(resource = LegacyResource.MENU)
public class MenuWidget
extends PaneEntity<MenuConfig>
{
   /** OWNER property: window for menubar or other widget for popup menu */
   private GenericWidget<?> owner;
   
   /** MENUBAR option: specifies whether this menu owned by a window or not  */
   private boolean menubar = false;
   
   /**
    * Default constructor.  
    * 
    * @param    dynamic
    *           Flag indicating if this is a static or dynamic resource.
    */
   public MenuWidget(boolean dynamic)
   {
      super(dynamic, new MenuConfig());
   }

   /**
    * Get MENUBAR option.
    * 
    * @return  See above.
    */
   public boolean isMenubar()
   {
      return menubar;
   }

   /**
    * Set MENUBAR option.
    * 
    * @return  See above.
    */
   public void setMenubar(boolean menubar)
   {
      this.menubar = menubar;
   }

   /**
    * Get owner widget.
    * 
    * @return  See above.
    */
   public GenericWidget<?> getOwner()
   {
      return owner;
   }

   /**
    * Set owner widget.
    * 
    * @return  See above.
    */
   public void setOwner(GenericWidget<?> owner)
   {
      this.owner = owner;
   }

   /**
    * Creates new menu as a proxy object (as a local resource).  This loads
    * the static menu definition.
    *
    * @param    <T> 
    *           Menu definition class type.
    * @param    defCls
    *           The class of menu definition.
    * @param    name
    *           The name of menu.          
    *
    * @return   The created menu widget.
    */
   public static <T extends MenuDefinition> T createStaticMenu(Class<T> defCls, String name)
   {
      MenuWidget menu = new MenuWidget(false);
      menu.name(name);
      
      final T menuDef;
      try
      {
         menuDef = defCls.getConstructor(new Class<?>[]{}).newInstance();
         menuDef.setup(menu);
      }
      catch (NoSuchMethodException    | 
             SecurityException        | 
             InstantiationException   | 
             IllegalAccessException   | 
             IllegalArgumentException | 
             InvocationTargetException e)
      {
         throw new RuntimeException("Failed to instantiate menu definition class", e);
      }
      
      return menuDef;
   }
}
