/*
** Module   : SubMenuDefinition.java
** Abstract : An abstract class. Its implementation will described concrete sub-menu definition. 
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 VIG 20141125 Created initial version.
*/
package com.goldencode.p2j.ui;


/**
 * Base class for menu definitions. One implementation for each menu.
 */
public abstract class SubMenuDefinition 
extends WidgetListBase<SubMenuWidget>
{
   /**  
    * Link to sub-menu widget, that this definition relates to. 
    */
   private SubMenuWidget self;
   
   /**
    * Get self sub-menu widget.
    * 
    * @return   See above.
    */
   public SubMenuWidget getSelf()
   {
      return self;
   }

   /**
    * Get self sub-menu widget.
    * 
    * @param   self
    * @throws  IllegalStateException
    *          If self is already initialized.
    */
   public void setSelf(SubMenuWidget self)
   {
      if (this.self != null) 
         throw new IllegalStateException("Self sub-menu widget is already initialized.");
      
      this.self = self;
   }

   /**
    * Sets the sub-menu owner menu or sub-menu.
    * 
    * @param  menu
    *         instance of <code>MenuWidget</code>
    */
   public void setParent(GenericWidget<?> menu)
   {
      // TODO implement
   }

   /**
    * Sets new value of SENSITIVE attribute.
    *
    * @param disabled
    *        New value of SENSITIVE attribute. <code>TRUE</code> means <code>SENSITIVE=FALSE</code>
    *        and vice versa:  <code>FALSE</code> means <code>SENSITIVE=TRUE</code>.
    */
   public void setDisabled(boolean disabled) 
   {
      this.self.setSensitive(!disabled);
   }
}
