/*
** Module   : SubMenuWidget.java
** Abstract : server side sub-menu widget implementation
**
** Copyright (c) 2014-2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------------------Description-----------------------------
** 001 VIG 20141124          Created initial version.
*/
package com.goldencode.p2j.ui;

import java.lang.reflect.*;

import com.goldencode.p2j.util.*;

/**
 * This class represents sub-menu widget.
 */
@LegacyResource(resource = LegacyResource.SUB_MENU)
public class SubMenuWidget
extends PaneEntity<SubMenuConfig>
{
   /**
    * Default constructor.  
    * 
    * @param    dynamic
    *           Flag indicating if this is a static or dynamic resource.
    */
   public SubMenuWidget(boolean dynamic)
   {
      super(dynamic, new SubMenuConfig());
   }

   /**
    * Creates new sub-menu as a proxy object (as a local resource).  This loads
    * the static sub-menu definition.
    *
    * @param    <T> 
    *           Sub-menu definition class type.
    * @param    defCls
    *           The class of sub-menu definition.
    * @param    name
    *           The name of sub-menu.          
    *
    * @return   The created sub-menu widget.
    */
   public static <T extends SubMenuDefinition> T createStaticSubMenu(Class<T> defCls, String name)
   {
      SubMenuWidget subMenu = new SubMenuWidget(false);
      subMenu.name(name);
      
      final T menuDef;
      try
      {
         menuDef = defCls.getConstructor(new Class<?>[]{}).newInstance();
         menuDef.setSelf(subMenu);
         menuDef.setup(subMenu);
      }
      catch (NoSuchMethodException    | 
             SecurityException        | 
             InstantiationException   | 
             IllegalAccessException   | 
             IllegalArgumentException | 
             InvocationTargetException e)
      {
         throw new RuntimeException("Failed to instantiate sub-menu definition class", e);
      }
      
      return menuDef;
   }
}
