/*
** Module   : WidgetListBase.java
** Abstract : Registers the widgets created as part of a container.
**
** Copyright (c) 2006-2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------------------Description-----------------------------
** 001 VIG 20141129          Created initial version.
*/

package com.goldencode.p2j.ui;

import java.util.*;

/**
 * This class provides a simple registration means for the widgets inside a container.
 * 
 *  @param   F
 *           Container class.
 */
abstract class WidgetListBase<F>
implements Settable<F>
{
   /** List of regular widgets. */
   private Map<String, GenericWidget<?>> widgetMap = new LinkedHashMap<>();

   /** Converted name to original name mapping */
   private Map<String, String> nameMap = new LinkedHashMap<String, String>();

   /** List of header widgets. */
   private Map<String, GenericWidget<?>> widgetHeaderMap = new LinkedHashMap<>();
   
   /**
    * Registers a widget with the frame.
    *
    * @param    name
    *           widget name
    * @param    widget
    *           instance of a widget to register
    */
   public void addWidget(String name, GenericWidget<?> widget)
   {
      widgetMap.put(name, widget);
      nameMap.put(name, name);
   }

   /**
    * Registers a widget with the frame.
    *
    * @param    convName
    *           converted widget name
    * @param    origName
    *           original widget name
    * @param    widget
    *           instance of a widget to register
    */
   public void addWidget(String convName, String origName, GenericWidget<?> widget)
   {
      widgetMap.put(convName, widget);
      nameMap.put(convName, origName);
   }

   /**
    * Registers a header widget with the frame.
    *
    * @param    name
    *           widget name
    * @param    widget
    *           instance of a widget to register
    */
   public void addHeaderWidget(String name, GenericWidget<?> widget)
   {
      widgetHeaderMap.put(name, widget);
   }
   
   /**
    * Gets the map of widgets registered with the frame.
    * 
    * @return   widget map.
    */
   public Map<String, GenericWidget<?>> getWidgets()
   {
      return widgetMap;
   }

   /**
    * Gets the map of names of widgets registered with the frame.
    * 
    * @return   name map.
    */
   public Map<String, String> getNames()
   {
      return nameMap;
   }

   /**
    * Gets the map of header widgets registered with the frame.
    * 
    * @return   widget map.
    */
   public Map<String, GenericWidget<?>> getHeaderWidgets()
   {
      return widgetHeaderMap;
   }
}
